Colors class

ANSI terminal color codes used by the CLI for consistent styling.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

blue → dynamic
no setter
bold → dynamic
no setter
cyan → dynamic
no setter
green → dynamic
no setter
magenta → dynamic
no setter
red → dynamic
no setter
reset → dynamic
no setter
white → dynamic
no setter
yellow → dynamic
no setter