DevforgeConfig class

Project-level configuration loaded from devforge.yaml.

Use DevforgeConfig.load to read the file; then use inputPath and outputPath to get custom paths for generators.

Constructors

DevforgeConfig({required InputPath? inputPath, required OutputPath? outputPath})
DevforgeConfig.load()
Load config from devforge.yaml
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputPath → InputPath?
final
outputPath → OutputPath?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited