ProcessRunner class

Central utility for running Flutter and Dart shell commands.

All process execution (e.g. flutter doctor, flutter clean, dart pub cache clean) should go through ProcessRunner so that working directory and error handling are consistent.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

runDart(List<String> args, {bool silent = false}) Future<int>
Run dart with the given args. Returns exit code.
runFlutter(List<String> args, {bool silent = false}) Future<int>
Run flutter with the given args. Returns exit code.