UserConfig class

Persists and loads the user's name (used in generated file headers).

Call load once at startup; then use userName, getUserName, and saveUserName as needed.

Constructors

UserConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

userName String
no setter

Static Methods

getUserName() Future<String?>
load() Future<void>
Call this once at app start
saveUserName(String name) Future<void>