OutputPath class
Output paths for generated files (API client, FCM, storage, etc.).
Constructors
- OutputPath({required String? apiClient, required String? loggerInterceptor, required String? assetsUtils, required String? fcmService, required String? refreshToken, required String? appStorageService, required String? sqfliteService, required String? paginationService, required String? theme, required String? translationKeys})
- OutputPath.fromYaml(dynamic yaml)
-
factory
Properties
- apiClient → String?
-
final
- appStorageService → String?
-
final
- assetsUtils → String?
-
final
- fcmService → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loggerInterceptor → String?
-
final
- paginationService → String?
-
final
- refreshToken → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqfliteService → String?
-
final
- theme → String?
-
final
- translationKeys → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited