Spinner class
Simple progress spinner for long-running operations.
Uses stdout and \r to overwrite the same line with rotating frames.
Use start before work and stop when done. Alternatively use
runWithSpinner to wrap an async function.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void -
stop(
{bool success = true}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
defaultFrames
→ const List<
String>